@@ -1211,15 +1211,12 @@ class Repo extends Object
 			{
 				chdir($tempPath);
 				exec('tar zxvf ' . $tmp_name . ' -C ' . $extractPath . ' 2>&1', $out );
-				\Filesystem::delete($tmp_name);
 			}
 			catch (Exception $e)
 			{
 				$this->setError(Lang::txt('COM_PROJECT_FILES_ERROR_UNZIP_FAILED'));
-				\Filesystem::delete($tmp_name);
 				return false;
 			}
-
 		}
 		else
 		{
@@ -1240,17 +1237,10 @@ class Repo extends Object
 			{
 				$zip->extractTo($extractPath);
 				$zip->close();
-
-				// Remove original file
-				\Filesystem::delete($tmp_name);
 			}
 			else
 			{
 				$this->setError(Lang::txt('COM_PROJECT_FILES_ERROR_UNZIP_FAILED'));
-
-				// Remove original file
-				\Filesystem::delete($tmp_name);
-
 				return false;
 			}
 		}
@@ -1373,9 +1363,6 @@ class Repo extends Object
 			}
 		}
 
-		\Filesystem::delete($extractPath);
-		Filesystem::deleteDirectory($extractPath);
-
 		return $z;
 	}
 
