@@ -34,6 +34,11 @@ namespace Components\Publications\Admin\Controllers;
 
 use Hubzero\Component\AdminController;
 use Components\Publications\Tables;
+use Request;
+use Config;
+use Route;
+use Lang;
+use App;
 
 /**
  * Manage publication licenses
@@ -43,39 +48,40 @@ class Licenses extends AdminController
 	/**
 	 * List resource types
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function displayTask()
 	{
 		// Incoming
-		$this->view->filters = array();
-		$this->view->filters['limit']    = Request::getState(
-			$this->_option . '.licenses.limit',
-			'limit',
-			Config::get('list_limit'),
-			'int'
+		$this->view->filters = array(
+			'limit' => Request::getState(
+				$this->_option . '.licenses.limit',
+				'limit',
+				Config::get('list_limit'),
+				'int'
+			),
+			'start' => Request::getState(
+				$this->_option . '.licenses.limitstart',
+				'limitstart',
+				0,
+				'int'
+			),
+			'search' => Request::getState(
+				$this->_option . '.licenses.search',
+				'search',
+				''
+			),
+			'sort' => Request::getState(
+				$this->_option . '.licenses.sort',
+				'filter_order',
+				'title'
+			),
+			'sort_Dir' => Request::getState(
+				$this->_option . '.licenses.sortdir',
+				'filter_order_Dir',
+				'ASC'
+			)
 		);
-		$this->view->filters['start']    = Request::getState(
-			$this->_option . '.licenses.limitstart',
-			'limitstart',
-			0,
-			'int'
-		);
-		$this->view->filters['search']     = trim(Request::getState(
-			$this->_option . '.licenses.search',
-			'search',
-			''
-		));
-		$this->view->filters['sort']     = trim(Request::getState(
-			$this->_option . '.licenses.sort',
-			'filter_order',
-			'title'
-		));
-		$this->view->filters['sort_Dir'] = trim(Request::getState(
-			$this->_option . '.licenses.sortdir',
-			'filter_order_Dir',
-			'ASC'
-		));
 
 		// Instantiate an object
 		$rt = new \Components\Publications\Tables\License($this->database);
@@ -99,60 +105,52 @@ class Licenses extends AdminController
 	/**
 	 * Add a new type
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function addTask()
 	{
-		$this->view->setLayout('edit');
 		$this->editTask();
 	}
 
 	/**
 	 * Edit a type
 	 *
-	 * @return     void
+	 * @param   object  $row
+	 * @return  void
 	 */
 	public function editTask($row=null)
 	{
-		if ($row)
-		{
-			$this->view->row = $row;
-		}
-		else
+		Request::setVar('hidemainmenu', 1);
+
+		if (!is_object($row))
 		{
 			// Incoming (expecting an array)
 			$id = Request::getVar('id', array(0));
-			if (is_array($id))
-			{
-				$id = $id[0];
-			}
-			else
-			{
-				$id = 0;
-			}
+			$id = is_array($id) ? $id[0] : $id;
 
 			// Load the object
-			$this->view->row = new \Components\Publications\Tables\License($this->database);
-			$this->view->row->loadLicense($id);
+			$row = new \Components\Publications\Tables\License($this->database);
+			$row->loadLicense($id);
 		}
 
+		$this->view->row = $row;
+
 		// Set any errors
 		if ($this->getError())
 		{
-			$this->view->setError($this->getError());
+			\Notify::error($this->getError());
 		}
 
-		// Push some styles to the template
-		$this->css();
-
 		// Output the HTML
-		$this->view->display();
+		$this->view
+			->setLayout('edit')
+			->display();
 	}
 
 	/**
-	 * Save a publication and fall through to edit view
+	 * Save record and fall through to edit view
 	 *
-	 * @return void
+	 * @return  void
 	 */
 	public function applyTask()
 	{
@@ -160,9 +158,10 @@ class Licenses extends AdminController
 	}
 
 	/**
-	 * Save a type
+	 * Save record
 	 *
-	 * @return     void
+	 * @param   boolean  $redirect
+	 * @return  void
 	 */
 	public function saveTask($redirect = false)
 	{
@@ -172,22 +171,20 @@ class Licenses extends AdminController
 		$fields = Request::getVar('fields', array(), 'post');
 		$fields = array_map('trim', $fields);
 
-		$url = Route::url('index.php?option=' . $this->_option . '&controller='
-			. $this->_controller . '&task=edit&id[]=' . $fields['id'], false);
+		$url = Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&task=edit&id=' . $fields['id'], false);
 
 		// Initiate extended database class
 		$row = new \Components\Publications\Tables\License($this->database);
 		if (!$row->bind($fields))
 		{
-			$this->addComponentMessage($row->getError(), 'error');
-			App::redirect($url);
+			App::redirect($url, $row->getError(), 'error');
 			return;
 		}
 
-		$row->customizable 	= Request::getInt('customizable', 0, 'post');
-		$row->agreement 	= Request::getInt('agreement', 0, 'post');
-		$row->active 		= Request::getInt('active', 0, 'post');
-		$row->icon			= $row->icon ? $row->icon : '/core/components/com_publications/site/assets/img/logos/license.gif';
+		$row->customizable = Request::getInt('customizable', 0, 'post');
+		$row->agreement    = Request::getInt('agreement', 0, 'post');
+		$row->active       = Request::getInt('active', 0, 'post');
+		$row->icon         = $row->icon ? $row->icon : '/core/components/com_publications/site/assets/img/logos/license.gif';
 
 		if (!$row->id)
 		{
@@ -197,8 +194,7 @@ class Licenses extends AdminController
 		// Check content
 		if (!$row->check())
 		{
-			$this->addComponentMessage($row->getError(), 'error');
-			$this->view->setLayout('edit');
+			$this->setError($row->getError());
 			$this->editTask($row);
 			return;
 		}
@@ -206,8 +202,7 @@ class Licenses extends AdminController
 		// Store new content
 		if (!$row->store())
 		{
-			$this->addComponentMessage($row->getError(), 'error');
-			$this->view->setLayout('edit');
+			$this->setError($row->getError());
 			$this->editTask($row);
 			return;
 		}
@@ -227,14 +222,23 @@ class Licenses extends AdminController
 				Lang::txt('COM_PUBLICATIONS_SUCCESS_LICENSE_SAVED')
 			);
 		}
-		return;
 	}
 
+	/**
+	 * Reorder up
+	 *
+	 * @return  void
+	 */
 	public function orderupTask()
 	{
 		$this->reorderTask(-1);
 	}
 
+	/**
+	 * Reorder down
+	 *
+	 * @return  void
+	 */
 	public function orderdownTask()
 	{
 		$this->reorderTask(1);
@@ -244,7 +248,8 @@ class Licenses extends AdminController
 	 * Reorders licenses
 	 * Redirects to license listing
 	 *
-	 * @return     void
+	 * @param   integer  $dir
+	 * @return  void
 	 */
 	public function reorderTask($dir = 0)
 	{
@@ -256,7 +261,7 @@ class Licenses extends AdminController
 
 		// Load row
 		$row = new \Components\Publications\Tables\License($this->database);
-		$row->loadLicense( (int) $id[0]);
+		$row->loadLicense((int) $id[0]);
 
 		// Update order
 		$row->changeOrder($dir);
@@ -270,9 +275,9 @@ class Licenses extends AdminController
 	 * Makes one license default
 	 * Redirects to license listing
 	 *
-	 * @return     void
+	 * @return  void
 	 */
-	public function makedefaultTask($dir = 0)
+	public function makedefaultTask()
 	{
 		// Check for request forgeries
 		Request::checkToken();
@@ -282,9 +287,10 @@ class Licenses extends AdminController
 
 		if (count($id) > 1)
 		{
-			$this->addComponentMessage(Lang::txt('COM_PUBLICATIONS_LICENSE_SELECT_ONE'), 'error');
 			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
+				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
+				Lang::txt('COM_PUBLICATIONS_LICENSE_SELECT_ONE'),
+				'error'
 			);
 			return;
 		}
@@ -295,7 +301,7 @@ class Licenses extends AdminController
 		$id = intval($id[0]);
 
 		// Load row
-		$row->loadLicense( $id );
+		$row->loadLicense($id);
 
 		// Make default
 		$row->main = 1;
@@ -303,9 +309,10 @@ class Licenses extends AdminController
 		// Save
 		if (!$row->store())
 		{
-			$this->addComponentMessage($row->getError(), 'error');
 			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
+				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
+				$row->getError(),
+				'error'
 			);
 			return;
 		}
@@ -324,9 +331,9 @@ class Licenses extends AdminController
 	 * Change license status
 	 * Redirects to license listing
 	 *
-	 * @return     void
+	 * @return  void
 	 */
-	public function changestatusTask($dir = 0)
+	public function changestatusTask()
 	{
 		// Check for request forgeries
 		Request::checkToken();
@@ -339,21 +346,25 @@ class Licenses extends AdminController
 
 		foreach ($ids as $id)
 		{
-			if (intval($id))
+			$id = intval($id);
+			if (!$id)
 			{
-				// Load row
-				$row->loadLicense( $id );
-				$row->active = $row->active == 1 ? 0 : 1;
+				continue;
+			}
 
-				// Save
-				if (!$row->store())
-				{
-					$this->addComponentMessage($row->getError(), 'error');
-					App::redirect(
-						Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-					);
-					return;
-				}
+			// Load row
+			$row->loadLicense($id);
+			$row->active = $row->active == 1 ? 0 : 1;
+
+			// Save
+			if (!$row->store())
+			{
+				App::redirect(
+					Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
+					$row->getError(),
+					'error'
+				);
+				return;
 			}
 		}
 
@@ -363,14 +374,4 @@ class Licenses extends AdminController
 			Lang::txt('COM_PUBLICATIONS_SUCCESS_LICENSE_PUBLISHED')
 		);
 	}
-
-	/**
-	 * Cancel a task (redirects to default task)
-	 *
-	 * @return	void
-	 */
-	public function cancelTask()
-	{
-		App::redirect(Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false));
-	}
 }
