@@ -25,7 +25,6 @@
  * HUBzero is a registered trademark of Purdue University.
  *
  * @package   hubzero-cms
- * @author    Shawn Rice <zooley@purdue.edu>
  * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
  * @license   http://opensource.org/licenses/MIT MIT
  */
@@ -35,25 +34,20 @@ defined('_HZEXEC_') or die();
 ?>
 <section class="main section">
 	<div class="subject">
-		<?php foreach ($this->notifications as $notification) { ?>
-			<p class="<?php echo $notification['type']; ?>"><?php echo $this->escape($notification['message']); ?></p>
-		<?php } ?>
-
 		<h3 class="post-comment-title">
-		<?php if ($this->model->id) { ?>
-			<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_EDIT_CATEGORY'); ?>
-		<?php } else { ?>
-			<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_NEW_CATEGORY'); ?>
-		<?php } ?>
+			<?php if ($this->category->get('id')) { ?>
+				<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_EDIT_CATEGORY'); ?>
+			<?php } else { ?>
+				<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_NEW_CATEGORY'); ?>
+			<?php } ?>
 		</h3>
 
 		<form action="<?php echo Route::url($this->offering->link() . '&active=discussions'); ?>" method="post" id="commentform">
 			<p class="comment-member-photo">
 				<?php
-				$jxuser = new \Hubzero\User\Profile();
-				$jxuser->load(User::get('id'));
+				$user = Components\Members\Models\Member::oneOrNew(User::get('id'));
 				?>
-				<img src="<?php echo $jxuser->getPicture(); ?>" alt="" />
+				<img src="<?php echo $user->picture(); ?>" alt="" />
 			</p>
 
 			<fieldset>
@@ -61,36 +55,51 @@ defined('_HZEXEC_') or die();
 					<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_SECTION'); ?> <span class="required"><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_REQUIRED'); ?></span>
 					<select name="fields[section_id]" id="field-section_id">
 						<option value="0"><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_SECTION_SELECT'); ?></option>
-					<?php foreach ($this->sections as $section) { ?>
-						<option value="<?php echo $section->id; ?>"<?php if ($this->model->section_id == $section->id) { echo ' selected="selected"'; } ?>><?php echo $this->escape(stripslashes($section->title)); ?></option>
-					<?php } ?>
+						<?php foreach ($this->forum->sections(array('state' => 1))->rows() as $section) { ?>
+							<option value="<?php echo $section->get('id'); ?>"<?php if ($this->category->get('section_id') == $section->get('id')) { echo ' selected="selected"'; } ?>><?php echo $this->escape(stripslashes($section->get('title'))); ?></option>
+						<?php } ?>
 					</select>
 				</label>
 
 				<label for="field-title">
 					<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_TITLE'); ?> <span class="required"><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_REQUIRED'); ?></span>
-					<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($this->model->title)); ?>" />
+					<input type="text" name="fields[title]" id="field-title" value="<?php echo $this->escape(stripslashes($this->category->get('title'))); ?>" />
 				</label>
 
 				<label for="field-description">
 					<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_DESCRIPTION'); ?>
-					<textarea name="fields[description]" id="field-description" cols="35" rows="5"><?php echo $this->escape(stripslashes($this->model->description)); ?></textarea>
+					<textarea name="fields[description]" id="field-description" cols="35" rows="5"><?php echo $this->escape(stripslashes($this->category->get('description'))); ?></textarea>
 				</label>
 
-				<label for="field-closed" id="comment-anonymous-label">
-					<input class="option" type="checkbox" name="fields[closed]" id="field-closed" value="3"<?php if ($this->model->closed) { echo ' checked="checked"'; } ?> />
-					<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_CLOSED'); ?>
-				</label>
+				<div class="grid">
+					<div class="col span6">
+						<label for="field-closed" id="comment-anonymous-label">
+							<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_LOCKED'); ?><br />
+							<input class="option" type="checkbox" name="fields[closed]" id="field-closed" value="3"<?php if ($this->category->get('closed')) { echo ' checked="checked"'; } ?> />
+							<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_CLOSED'); ?>
+						</label>
+					</div>
+					<div class="col span6 omega">
+						<label for="field-access">
+							<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_ACCESS_DESCRIPTION'); ?>:
+							<select name="fields[access]" id="field-access">
+								<option value="1"<?php if ($this->category->get('access') == 1) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_READ_ACCESS_OPTION_PUBLIC'); ?></option>
+								<option value="2"<?php if ($this->category->get('access') == 2) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_READ_ACCESS_OPTION_REGISTERED'); ?></option>
+								<option value="5"<?php if ($this->category->get('access') == 5) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_FIELD_READ_ACCESS_OPTION_PRIVATE'); ?></option>
+							</select>
+						</label>
+					</div>
+				</div>
 
 				<p class="submit">
 					<input type="submit" value="<?php echo Lang::txt('PLG_COURSES_DISCUSSIONS_SUBMIT'); ?>" />
 				</p>
 			</fieldset>
-			<input type="hidden" name="fields[alias]" value="<?php echo $this->model->alias; ?>" />
-			<input type="hidden" name="fields[id]" value="<?php echo $this->model->id; ?>" />
+			<input type="hidden" name="fields[alias]" value="<?php echo $this->escape($this->category->get('alias')); ?>" />
+			<input type="hidden" name="fields[id]" value="<?php echo $this->escape($this->category->get('id')); ?>" />
 			<input type="hidden" name="fields[state]" value="1" />
-			<input type="hidden" name="fields[scope]" value="course" />
-			<input type="hidden" name="fields[scope_id]" value="<?php echo $this->offering->get('id'); ?>" />
+			<input type="hidden" name="fields[scope]" value="<?php echo $this->escape($this->forum->get('scope')); ?>" />
+			<input type="hidden" name="fields[scope_id]" value="<?php echo $this->escape($this->forum->get('scope_id')); ?>" />
 
 			<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 			<input type="hidden" name="gid" value="<?php echo $this->course->get('alias'); ?>" />
