@@ -25,7 +25,6 @@
  * HUBzero is a registered trademark of Purdue University.
  *
  * @package   hubzero-cms
- * @author    Shawn Rice <zooley@purdue.edu>
  * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
  * @license   http://opensource.org/licenses/MIT MIT
  */
@@ -38,10 +37,10 @@ defined('_HZEXEC_') or die();
 	$name = Lang::txt('PLG_GROUPS_BLOG_ANONYMOUS');
 	if (!$this->comment->get('anonymous'))
 	{
-		$name = $this->escape(stripslashes($this->comment->creator()->get('name', $name)));
-		if ($this->comment->creator()->get('public'))
+		$name = $this->escape(stripslashes($this->comment->creator->get('name', $name)));
+		if (in_array($this->comment->creator->get('access'), User::getAuthorisedViewLevels()))
 		{
-			$name = '<a href="' . Route::url($this->comment->creator()->getLink()) . '">' . $name . '</a>';
+			$name = '<a href="' . Route::url($this->comment->creator->link()) . '">' . $name . '</a>';
 		}
 	}
 
@@ -51,13 +50,13 @@ defined('_HZEXEC_') or die();
 	}
 	else
 	{
-		$comment  = $this->comment->content('parsed');
+		$comment  = $this->comment->content();
 	}
 ?>
 	<li class="comment <?php echo $cls; ?>" id="c<?php echo $this->comment->get('id'); ?>">
 		<p class="comment-member-photo">
 			<a class="comment-anchor" name="c<?php echo $this->comment->get('id'); ?>"></a>
-			<img src="<?php echo $this->comment->creator()->getPicture($this->comment->get('anonymous')); ?>" alt="" />
+			<img src="<?php echo $this->comment->creator->picture($this->comment->get('anonymous')); ?>" alt="" />
 		</p>
 		<div class="comment-content">
 			<p class="comment-title">
@@ -100,7 +99,7 @@ defined('_HZEXEC_') or die();
 					<label for="comment_<?php echo $this->comment->get('id'); ?>_content">
 						<span class="label-text"><?php echo Lang::txt('PLG_GROUPS_BLOG_FIELD_COMMENTS'); ?></span>
 						<?php
-						echo $this->editor('comment[content]', $this->comment->content('raw'), 35, 4, 'comment_' . $this->comment->get('id') . '_content', array('class' => 'minimal no-footer'));
+						echo $this->editor('comment[content]', $this->comment->get('content'), 35, 4, 'comment_' . $this->comment->get('id') . '_content', array('class' => 'minimal no-footer'));
 						?>
 					</label>
 
@@ -165,6 +164,8 @@ defined('_HZEXEC_') or die();
 						<input type="hidden" name="task" value="view" />
 						<input type="hidden" name="action" value="savecomment" />
 
+						<?php echo Html::input('token'); ?>
+
 						<label for="comment_<?php echo $this->comment->get('id'); ?>_content">
 							<span class="label-text"><?php echo Lang::txt('PLG_GROUPS_BLOG_FIELD_COMMENTS'); ?></span>
 							<?php
@@ -189,16 +190,24 @@ defined('_HZEXEC_') or die();
 		<?php
 		if ($this->depth < $this->config->get('comments_depth', 3))
 		{
+			$replies = $this->comment->replies()
+				->whereIn('state', array(
+					Components\Blog\Models\Comment::STATE_PUBLISHED,
+					Components\Blog\Models\Comment::STATE_FLAGGED
+				))
+				->ordered()
+				->rows();
+
 			$this->view('_list', 'comments')
-			     ->set('group', $this->group)
-			     ->set('parent', $this->comment->get('id'))
-			     ->set('cls', $cls)
-			     ->set('depth', $this->depth)
-			     ->set('option', $this->option)
-			     ->set('comments', $this->comment->replies())
-			     ->set('config', $this->config)
-			     ->set('base', $this->base)
-			     ->display();
+				->set('group', $this->group)
+				->set('parent', $this->comment->get('id'))
+				->set('cls', $cls)
+				->set('depth', $this->depth)
+				->set('option', $this->option)
+				->set('comments', $replies)
+				->set('config', $this->config)
+				->set('base', $this->base)
+				->display();
 		}
 		?>
 	</li>
\ No newline at end of file
